package com.example.split_remote_config_plugin

import android.content.Context
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.split.android.client.SplitClient
import io.split.android.client.SplitClientConfig
import io.split.android.client.SplitFactoryBuilder
import io.split.android.client.api.Key

/** SplitRemoteConfigPlugin */
class SplitRemoteConfigPlugin : FlutterPlugin, MethodCallHandler {

    // Get Split Client instance
    private var client: SplitClient? = null

    private lateinit var channel: MethodChannel
    private lateinit var applicationContext: Context

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        applicationContext = flutterPluginBinding.applicationContext

        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "native_channel_id_123")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "initiate" -> {
                initiateSplit()
                result.success("Initiated successfully")
            }
            "isEnabled" -> {
                val isEnabled = checkIfEnabled(call.argument<String>("key")!!)
                result.success(isEnabled)
            }
            else -> {
                result.error("123", "Unknown operation", null)
            }
        }
    }


    private fun checkIfEnabled(key: String): Boolean {
        return client?.getTreatment(key) == "on"
    }

    private fun initiateSplit() {

        if (client != null) return

        //API Key
        val apikey = "cfa8ltltbok2ds............"

        // Build SDK configuration by default
        val config = SplitClientConfig.builder()
            .build()

        // Create a new user key to be evaluated
        val matchingKey = "key"
        val k = Key(matchingKey)

        // Create factory
        val splitFactory = SplitFactoryBuilder.build(apikey, k, config, applicationContext)

        client = splitFactory.client()
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }
}
